@@ -6,7 +6,7 @@
 # October 16, 2007
 # ----------------------------------------
 
-from utils import runShellCommand, ynask, reverse, writefile, killfiles, downloader
+from utils import runShellCommand, ynask, reverse, writefile, killfiles, downloader, getURLName, fixpaths
 import sys
 import os
 import getopt
@@ -18,30 +18,31 @@ class Frame:
     # set default values
     prefix = ''
     ccflags, fcflags, noopt = ['-O3','-O3','']
-    mpibindir = ''
-    mpiincdir = ''
-    mpicc, mpif77 = ['', '']
-    make         = 'make'
-    plat         = 'LINUX'
-    mangling     = ''
-    blaslib      = ''
-    blacslib     = ''
-    blacsClib    = ''
-    blacsF77lib  = ''
-    lapacklib    = ''
-    scalapacklib = ''
+    mpibindir = ''               # directory containing mpicc and mpif77
+    mpiincdir = ''               # directory containing mpi.h
+    mpicc, mpif77 = ['', '']     # the mpicc and mpif77 commands
+    make         = 'make'        # the "make" command
+    plat         = 'LINUX'       
+    mangling     = ''            # sets the mangling type for Fortran to C calls
+    blaslib      = ''            # the blas library
+    blacslib     = ''            # the blacs library
+    blacsClib    = ''            # the blacs C library
+    blacsF77lib  = ''            # the blacs F77 library
+    lapacklib    = ''            # lapack library
+    scalapacklib = ''            # scalapack library
     proxy        = 0
-    downblas     = 0
-    downblacs    = 1
-    downlapack   = 0
-    ldflags      = ''
-    testing      = 1
-    downcmd      = ''
+    downblas     = 0             # whether or not to download reference blas
+    downblacs    = 1             # whether or not to download reference blacs
+    downlapack   = 0             # whether or not to download reference lapack
+    ldflags_c    = ''            # loader flags when main program is in C
+    ldflags_f77  = ''            # loader flags when main program is in Fortran
+    testing      = 1             # whether on not to compile and run LAPACK and ScaLAPACK test programs
+    downcmd      = ''            # the command used to download stuff
     blasurl      = 'http://netlib.org/blas/blas.tgz'
-    lapackurl    = 'http://netlib.org/lapack/lapack-lite-3.1.1.tgz'
+    lapackurl    = 'http://netlib.org/lapack/lapack.tgz'
     blacsurl     = 'http://netlib.org/blacs/mpiblacs.tgz'
     scalapackurl = 'http://netlib.org/scalapack/scalapack-1.8.0.tgz'
-    ranlib       = ''
+    ranlib       = ''            # the ranlib command
     clean        = 0
 
     def __init__(self, argv):
@@ -163,7 +164,13 @@ needed in the case where testing is disabled by means of the
                                  in LAPACK and ScaLAPACK.
                                  See LAPACK and ScaLAPACK documentation.
 
-          --ldflags=[flags]    : loader flags
+          --ldflags_c=[flags]  : loader flags when main program is in C. Some compilers (e.g. PGI) require 
+                                 different options when linking C main programs to Fortran subroutines
+                                 and vice-versa
+
+          --ldflags_f77=[flags]: loader flags when main program is in Fortran. Some compilers (e.g. PGI) require 
+                                 different options when linking Fortran main programs to C subroutines
+                                 and vice-versa
 
           --makecmd=[CMD]      : the make command
                                  (make by default)
@@ -211,7 +218,7 @@ Note: If you want use a proxy for downloading, the http_proxy environment variab
         try:
           opts, args = getopt.getopt(sys.argv[1:], "h", ["help","prefix=",
           "ccflags=", "fcflags=", "noopt=", "makecmd=", "mpibindir=", "mpiincdir=", "blacslib=",
-          "blacsclib=", "blacsf77lib=", "blaslib=", "lapacklib=", "ldflags=","mpicc=","mpif77=",
+          "blacsclib=", "blacsf77lib=", "blaslib=", "lapacklib=", "ldflags_c=", "ldflags_f77=","mpicc=","mpif77=",
           "downblas", "downblacs", "downlapack", "notesting","clean"])
         except getopt.error, msg:
           print msg
@@ -227,8 +234,8 @@ Note: If you want use a proxy for downloading, the http_proxy environment variab
                 Frame.clean = 1
                 return;
             elif(o == '--prefix'):
-                Frame.prefix = a
-                print 'Install directory is...', a
+                Frame.prefix = fixpaths(a)
+                print 'Install directory is...', Frame.prefix
             elif(o == '--ccflags'):
                 Frame.ccflags = a
                 print 'C flags are ', a
@@ -241,11 +248,11 @@ Note: If you want use a proxy for downloading, the http_proxy environment variab
             elif(o=='--makecmd'):
                 Frame.make = a
             elif(o=='--mpibindir'):
-                Frame.mpibindir = a
-                print 'MPI bin dir is ', a
+                Frame.mpibindir = fixpaths(a)
+                print 'MPI bin dir is ', Frame.mpibindir
             elif(o=='--mpiincdir'):
-                Frame.mpiincdir = a
-                print 'MPI include dir is ', a
+                Frame.mpiincdir = fixpaths(a)
+                print 'MPI include dir is ', Frame.mpiincdir
             elif(o=='--mpicc'):
                 Frame.mpicc = a
                 print 'mpicc is ', a
@@ -253,18 +260,18 @@ Note: If you want use a proxy for downloading, the http_proxy environment variab
                 Frame.mpif77 = a
                 print 'mpif77 is ', a
             elif(o == '--blacslib'):
-                Frame.blacslib = a
+                Frame.blacslib = fixpaths(a)
                 Frame.downblacs = 0
             elif(o == '--blacsclib'):
-                Frame.blacsClib = a
+                Frame.blacsClib = fixpaths(a)
                 Frame.downblacs = 0
             elif(o == '--blacsf77lib'):
-                Frame.blacsF77lib = a
+                Frame.blacsF77lib = fixpaths(a)
                 Frame.downblacs = 0
             elif (o == '--blaslib'):
-                Frame.blaslib = a
+                Frame.blaslib = fixpaths(a)
             elif (o == '--lapacklib'):
-                Frame.lapacklib = a
+                Frame.lapacklib = fixpaths(a)
             elif (o == '--downblas'):
                 Frame.downblas = 1
             elif (o == '--downblacs'):
@@ -273,8 +280,10 @@ Note: If you want use a proxy for downloading, the http_proxy environment variab
                 Frame.downlapack = 1
             elif (o == '--notesting'):
                 Frame.testing = 0
-            elif (o == '--ldflags'):
-                Frame.ldflags = a
+            elif (o == '--ldflags_c'):
+                Frame.ldflags_c = a
+            elif (o == '--ldflags_f77'):
+                Frame.ldflags_f77 = a
 
  
     # look for MPI
@@ -431,7 +440,7 @@ in the PATH environment variable.
             sys.exit()
 
         # cleanup        
-        killfiles(['tmpf.f','tmpf'])
+        killfiles(['tmpf.f','tmpf','tmpf.o'])
         print 'yes'
 
         return 0;
@@ -516,7 +525,7 @@ in the PATH environment variable.
 
         ccomm = Frame.mpicc+' '+Frame.ccflags+' '+Frame.mangling+' -c -o tmpc.o tmpc.c'
         fcomm = Frame.mpif77+' '+Frame.fcflags+' -c -o tmpf.o tmpf.f'
-        lcomm = Frame.mpif77+' '+Frame.ldflags+' -o lnk tmpf.o tmpc.o'
+        lcomm = Frame.mpif77+' '+Frame.ldflags_c+' -o lnk tmpf.o tmpc.o'
       
         (output, error, retz) = runShellCommand(ccomm)
         if(retz != 0):
@@ -551,47 +560,80 @@ in the PATH environment variable.
           
     def set_download(self):
         """ Figures out how to download files """
-        print 'Setting download command...',
+        print 'Setting download command...'
+        wget = 0
+        urllib = 0
         # look for proxy setting in the environnement variables
-        proxy_http=str(os.getenv('http_proxy')) 
-		# if proxy_http found in the environnement, we are going to use wget as download command
-        if (proxy_http):
-		   Frame.proxy=1
-		   urllib=0
+        proxy_http=str(os.getenv('http_proxy'))
+        # if proxy_http found in the environnement, we are going to use wget as download command
+        if (proxy_http != 'None'):
+            Frame.proxy=1
+            urllib=0
         else:    
-           try:
-            # check if the urllib2 module is included in the
-            # python installation. If yes files are downloaded with urllib2            
-               import urllib2
-               urllib=1
-               Frame.downcmd = 'urllib2'
-               print Frame.downcmd
-               return
-           except ImportError:
-               urllib=0
+            try:
+                # check if the urllib2 module is included in the
+                # python installation. If yes files are downloaded with urllib2            
+                print "Checking availability of urllib...",
+                import urllib2
+                urllib=1
+                print "available"
+                print "Testing urllib...",
+                try:
+#                     name = getURLName('http://www.netlib.org/lapack/index')
+                    url = urllib2.urlopen('http://www.netlib.org/lapack/index')
+                    f = open(name,'w')
+                    for line in url.readlines():
+                        f.write(line)
+                    url.close()
+                    f.close()
+                except:
+                    print "not working"
+                    urllib = -1
+                else:
+                    print "working"
+                    Frame.downcmd = 'urllib2'
+                    os.remove('index')
+                    return
+            except ImportError:
+                print "not available"
+                urllib=0
 
-        if(not urllib):
+        if(urllib <= 0):
             # if urllib2 is not present checks if wget is present
             # in the PATH and if yes it sets the download command
             # to be wget
+            print "Checking availablility of wget...",
             path=str(os.getenv('PATH')).split(os.pathsep)
             for i in path:
                 if (os.path.isfile(os.path.join(i,'wget'))):
+                    print "available"
+                    wget = 1
+                    break
+
+            if(wget == 1):
+                # test wget
+                if (proxy_http != 'None'):
+                    print "Testing wget through the "+proxy_http+" proxy...",
+                else:
+                    print "Testing wget...",
+                try:
+                    comm = 'wget http://www.netlib.org/lapack/index'
+                    (output, error, retz) = runShellCommand(comm)
+                    if(retz != 0):
+                        raise
+                except:
+                    print 'not working.'
+                    wget = -1
+                else:
+                    print 'working'
                     Frame.downcmd='wget'
-                    print Frame.downcmd
-                    if (proxy_http):
-					   print 'Using the following proxy to download: ',proxy_http
-					   print 'Testing download via proxy...',
-					   comm = 'wget http://www.netlib.org/lapack/lapack-3.1.1.changes'
-					   (output, error, retz) = runShellCommand(comm)
-					   if(retz != 0):
-						  print 'not working...aborting'
-						  print 'Please change your proxy settings:', proxy_http, 'is not working'
-						  sys.exit()
-					   print 'working'
-					   os.remove('lapack-3.1.1.changes')
+                    os.remove('index')
                     return
-            
+            else:
+                # wget not available
+                print "not available"
+                wget=0
+
 
     def set_ranlib(self):
         """ Sets the ranlib command """
@@ -628,13 +670,15 @@ in the PATH environment variable.
             # The Intel FORTRAN compiler requires -nofor_main flag
             # for the linking and the -mp flag to maintain the 
             # floating-point precision
-            Frame.ldflags += ' -nofor_main'
+            Frame.ldflags_c   += ' -nofor_main'
+            Frame.ldflags_f77 += ''
             Frame.noopt += ' -mp'
             print 'Intel'
         elif (self.fc_is_gnu()):
             print 'GNU'
         elif (self.fc_is_pgi()):
-            Frame.ldflags += ' -Mnomain'
+            Frame.ldflags_c   += ' -Mnomain'
+            Frame.ldflags_f77 += ''
         else:
             print 'unknown'
 
@@ -652,7 +696,8 @@ in the PATH environment variable.
 
         print 'Selected C compiler flags: '+self.ccflags
         print 'Selected Fortran77 compiler flags: '+self.fcflags
-        print 'Selected loader flags: '+self.ldflags
+        print 'Selected loader flags (C main): '+self.ldflags_c
+        print 'Selected loader flags (F77 main): '+self.ldflags_f77
         print 'Selected NOOPT flags: '+self.noopt
 
         return
